# -*- coding: utf-8 -*-

"""
Setuptools setup for the module :mod:`mrtoolstheme`.

.. moduleauthor:: Michael Rippstein <info@anatas.ch>

:copyright: Copyright 2022 by Michael Rippstein.
:license: AGPL, see LICENSE for details.
"""

from setuptools import setup

setup()
